@@ -39,10 +39,6 @@
 
 #include "games-runtime.h"
 
-#ifdef HAVE_HILDON
-static osso_context_t *osso_context;
-#endif
-
 #if defined(G_OS_WIN32) && !defined(ENABLE_BINRELOC)
 #error binreloc must be enabled on win32
 #endif
@@ -251,54 +247,6 @@ static const DerivedDirectory derived_directories[] = {
 
 typedef int _assertion[G_N_ELEMENTS (derived_directories) + GAMES_RUNTIME_FIRST_DERIVED_DIRECTORY == GAMES_RUNTIME_LAST_DIRECTORY ? 1 : -1];
 
-#if !GTK_CHECK_VERSION (2, 17, 0)
-/* Since version 2.17.0, gtk has default about dialogue hook functions
- * using gtk_show_uri(). For earlier versions, we need to implement
- * our own hooks.
- */
-
-static void
-about_url_hook (GtkAboutDialog *about,
-                const char *uri,
-                gpointer user_data)
-{
-  GdkScreen *screen;
-  GError *error = NULL;
-
-  screen = gtk_widget_get_screen (GTK_WIDGET (about));
-
-  if (!games_show_uri (screen, uri, gtk_get_current_event_time (), &error)) {
-    games_show_error (GTK_WIDGET (about),
-                      error,
-                      "%s", _("Could not show link"));
-    g_error_free (error);
-  }
-}
-
-static void
-about_email_hook (GtkAboutDialog *about,
-                  const char *email_address,
-                  gpointer user_data)
-{
-  char *uri;
-
-#if GLIB_CHECK_VERSION (2, 16, 0)
-  char *escaped_email_address;
-
-  escaped_email_address = g_uri_escape_string (email_address, NULL, FALSE);
-  uri = g_strdup_printf ("mailto:%s", escaped_email_address);
-  g_free (escaped_email_address);
-#else
-  /* Not really correct, but the best we can do */
-  uri = g_strdup_printf ("mailto:%s", email_address);
-#endif
-
-  about_url_hook (about, uri, user_data);
-  g_free (uri);
-}
-
-#endif /* GTK < 2.17.0 */
-
 /* public API */
 
 /**
@@ -385,66 +333,13 @@ games_runtime_init (const char *name)
   retval = TRUE;
 #endif /* ENABLE_BINRELOC */
 
-  if (strcmp (app_name, "aisleriot") == 0) {
-    gpl_version = 3;
-  } else {
-    gpl_version = 2;
-  }
-
-#if !GTK_CHECK_VERSION (2, 17, 0)
-  gtk_about_dialog_set_url_hook (about_url_hook, NULL, NULL);
-  gtk_about_dialog_set_email_hook (about_email_hook, NULL, NULL);
-#endif
+  gpl_version = 2;
 
   _games_profile_end ("games_runtime_init");
 
   return retval;
 }
 
-#ifdef HAVE_HILDON
-
-/**
- * games_runtime_init_with_osso:
- *
- * Like games_runtime_init(), but also initialises the osso context.
- *
- * NOTE: This must be called before using ANY other glib/gtk/etc function!
- * 
- * Returns: %TRUE iff initialisation succeeded
- */
-gboolean
-games_runtime_init_with_osso (const char *name,
-                              const char *service_name)
-{
-  if (!games_runtime_init (name))
-    return FALSE;
-
-  osso_context = osso_initialize (service_name, VERSION, FALSE, NULL);
-  if (osso_context == NULL) {
-    g_printerr ("Failed to initialise osso\n");
-    return FALSE;
-  }
-
-  return TRUE;
-}
-
-/**
- * games_runtime_get_osso_context:
- *
- * Returns the osso context. May only be called after
- * games_runtime_init_with_osso().
- *
- * Returns: a #osso_context_t
- */
-osso_context_t*
-games_runtime_get_osso_context (void)
-{
-  g_assert (osso_context != NULL);
-  return osso_context;
-}
-
-#endif /* HAVE_HILDON */
-
 /**
  * games_runtime_shutdown:
  *
@@ -462,18 +357,10 @@ games_runtime_shutdown (void)
 
   g_free (app_name);
   app_name = NULL;
-
-#ifdef HAVE_HILDON
-  if (osso_context != NULL) {
-    osso_deinitialize (osso_context);
-    osso_context = NULL;
-  }
-#endif /* HAVE_HILDON */
 }
 
 /**
  * games_runtime_get_directory:
- * @runtime: the #GamesProgram instance
  * @directory:
  *
  * Returns: the path to use for @directory
@@ -562,7 +449,6 @@ games_runtime_get_directory (GamesRuntimeDirectory directory)
 
 /**
  * games_runtime_get_file:
- * @runtime: the #GamesProgram instance
  * @directory:
  * @name:
  *
