@@ -21,10 +21,6 @@
 
 #include <glib.h>
 
-#ifdef HAVE_HILDON
-#include <libosso.h>
-#endif
-
 G_BEGIN_DECLS
 
 typedef enum {
@@ -62,11 +58,6 @@ typedef enum {
 } GamesRuntimeDirectory;
 
 gboolean        games_runtime_init             (const char *name);
-#ifdef HAVE_HILDON
-gboolean        games_runtime_init_with_osso   (const char *name,
-                                                const char *service_name);
-osso_context_t* games_runtime_get_osso_context (void);
-#endif /* HAVE_HILDON */
 void            games_runtime_shutdown         (void);
 const char     *games_runtime_get_directory    (GamesRuntimeDirectory directory);
 char           *games_runtime_get_file         (GamesRuntimeDirectory directory,
