@@ -18,7 +18,13 @@ function load_theme(stage, theme)
 	theme.loaded = true;
 
 	for(actor in theme.textures)
+	{
+	    if(theme.textures[actor].get_parent())
+	        continue;
+	    
 		stage.add_actor(theme.textures[actor]);
+		theme.textures[actor].hide();
+	}
 }
 
 function load_themes()
